@@ -1,7 +1,6 @@
 """Command-line interface."""
 import logging
 import sys
-import traceback
 from typing import List
 from typing import Optional
 
@@ -22,11 +21,6 @@ from stac_api_validator.validations import validate_api
     required=True,
     help="STAC API Root / Landing Page URL",
 )
-@click.option(
-    "--post/--no-post",
-    default=True,
-    help="Test all validations with POST method for requests in addition to GET",
-)
 @click.option(
     "--collection",
     help="The name of the collection to use for item-search, collections, and features tests.",
@@ -54,13 +48,22 @@ from stac_api_validator.validations import validate_api
     ),
     help="The conformance classes to validate.",
 )
+@click.option(
+    "--auth-bearer-token",
+    help="Authorization Bearer token value to append to all requests.",
+)
+@click.option(
+    "--auth-query-parameter",
+    help="Query pararmeter key and value to pass for authorization, e.g., 'key=xyz'.",
+)
 def main(
     log_level: str,
     root_url: str,
-    post: bool,
     conformance_classes: List[str],
     collection: Optional[str],
     geometry: Optional[str],
+    auth_bearer_token: Optional[str] = None,
+    auth_query_parameter: Optional[str] = None,
 ) -> int:
     """STAC API Validator."""
 
@@ -69,29 +72,29 @@ def main(
     try:
         (warnings, errors) = validate_api(
             root_url=root_url,
-            post=post,
             conformance_classes=conformance_classes,
             collection=collection,
             geometry=geometry,
+            auth_bearer_token=auth_bearer_token,
+            auth_query_parameter=auth_query_parameter,
         )
     except Exception as e:
-        print(f"Failed.\nError {root_url}: {type(e)} {str(e)}")
-        traceback.print_exc()
+        click.secho(f"Failed.\nError {root_url}: {type(e)} {str(e)}", fg="red")
         return 1
 
     if warnings:
-        print("warnings:")
+        click.secho("Warnings:", fg="blue")
     else:
-        print("warnings: none")
+        click.secho("Warnings: none", fg="green")
     for warning in warnings:
-        print(f"- {warning}")
+        click.secho(f"- {warning}")
 
     if errors:
-        print("errors:")
+        click.secho("Errors:", fg="red")
+        for error in errors:
+            click.secho(f"- {error}")
     else:
-        print("errors: none")
-    for error in errors:
-        print(f"- {error}")
+        click.secho("Errors: none", fg="green")
 
     if errors:
         return 1
